==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/GroupSchemaDefinitions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupSchemaBase;
import com.okta.sdk.resource.model.GroupSchemaCustom;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GroupSchemaDefinitions
 */
@JsonPropertyOrder({ GroupSchemaDefinitions.JSON_PROPERTY_BASE, GroupSchemaDefinitions.JSON_PROPERTY_CUSTOM })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GroupSchemaDefinitions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE = "base";
    private GroupSchemaBase base;

    public static final String JSON_PROPERTY_CUSTOM = "custom";
    private GroupSchemaCustom custom;

    public GroupSchemaDefinitions() {
    }

    public GroupSchemaDefinitions base(GroupSchemaBase base) {

        this.base = base;
        return this;
    }

    /**
     * Get base
     *
     * @return base
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaBase getBase() {
        return base;
    }

    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBase(GroupSchemaBase base) {
        this.base = base;
    }

    public GroupSchemaDefinitions custom(GroupSchemaCustom custom) {

        this.custom = custom;
        return this;
    }

    /**
     * Get custom
     *
     * @return custom
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaCustom getCustom() {
        return custom;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustom(GroupSchemaCustom custom) {
        this.custom = custom;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupSchemaDefinitions groupSchemaDefinitions = (GroupSchemaDefinitions) o;
        return Objects.equals(this.base, groupSchemaDefinitions.base)
                && Objects.equals(this.custom, groupSchemaDefinitions.custom);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(base, custom);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupSchemaDefinitions {\n");
        sb.append("    base: ").append(toIndentedString(base)).append("\n");
        sb.append("    custom: ").append(toIndentedString(custom)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/GroupSchemaDefinitions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GroupSchemaBase;
import com.okta.sdk.resource.model.GroupSchemaCustom;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GroupSchemaDefinitions
 */
@JsonPropertyOrder({ GroupSchemaDefinitions.JSON_PROPERTY_BASE, GroupSchemaDefinitions.JSON_PROPERTY_CUSTOM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GroupSchemaDefinitions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BASE = "base";
    private GroupSchemaBase base;

    public static final String JSON_PROPERTY_CUSTOM = "custom";
    private GroupSchemaCustom custom;

    public GroupSchemaDefinitions() {
    }

    public GroupSchemaDefinitions base(GroupSchemaBase base) {

        this.base = base;
        return this;
    }

    /**
     * Get base
     *
     * @return base
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaBase getBase() {
        return base;
    }

    @JsonProperty(JSON_PROPERTY_BASE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBase(GroupSchemaBase base) {
        this.base = base;
    }

    public GroupSchemaDefinitions custom(GroupSchemaCustom custom) {

        this.custom = custom;
        return this;
    }

    /**
     * Get custom
     *
     * @return custom
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GroupSchemaCustom getCustom() {
        return custom;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustom(GroupSchemaCustom custom) {
        this.custom = custom;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GroupSchemaDefinitions groupSchemaDefinitions = (GroupSchemaDefinitions) o;
        return Objects.equals(this.base, groupSchemaDefinitions.base)
                && Objects.equals(this.custom, groupSchemaDefinitions.custom);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(base, custom);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GroupSchemaDefinitions {\n");
        sb.append("    base: ").append(toIndentedString(base)).append("\n");
        sb.append("    custom: ").append(toIndentedString(custom)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
